@@ -8,7 +8,7 @@
 # License   : Revised BSD License
 # -----------------------------------------------------------------------------
 # Creation  : 26-Apr-2010
-# Last mod  : 02-Jun-2012
+# Last mod  : 11-Jun-2012
 # -----------------------------------------------------------------------------
 
 """
@@ -42,7 +42,7 @@ from __future__ import with_statement
 import base64, bz2, hashlib, os, random, sys, re, string, tempfile, subprocess, types, functools
 import fabric, fabric.api, fabric.operations, fabric.context_managers
 
-VERSION     = "0.2.8"
+VERSION     = "0.2.9"
 
 RE_SPACES   = re.compile("[\s\t]+")
 MAC_EOL     = "\n"
@@ -361,34 +361,27 @@ def file_read(location):
 
 def file_exists(location):
 	"""Tests if there is a *remote* file at the given location."""
-	return run('test -e "%s" && echo OK ; true' % (location)) == "OK"
+	return run('test -e "%s" && echo OK ; true' % (location)).endswith("OK")
 
 def file_is_file(location):
-	return run("test -f '%s' && echo OK ; true" % (location)) == "OK"
+	return run("test -f '%s' && echo OK ; true" % (location)).endswith("OK")
 
 def file_is_dir(location):
-	return run("test -d '%s' && echo OK ; true" % (location)) == "OK"
+	return run("test -d '%s' && echo OK ; true" % (location)).endswith("OK")
 
 def file_is_link(location):
-	return run("test -L '%s' && echo OK ; true" % (location)) == "OK"
+	return run("test -L '%s' && echo OK ; true" % (location)).endswith("OK")
 
 def file_attribs(location, mode=None, owner=None, group=None, recursive=False):
 	"""Updates the mode/owner/group for the remote file at the given
 	location."""
-	# FIXME: Not sure this is the right way to do it, maybe we should
-	# have USER/SUDO/USER+SUDO modes instead?
-	def run_or_sudo(cmd):
-		with fabric.api.settings(warn_only=True):
-			r = run(cmd)
-			if r.return_code != 0:
-				sudo(cmd)
 	recursive = recursive and "-R " or ""
 	if mode:
-		run_or_sudo('chmod %s %s "%s"' % (recursive, mode,  location))
+		run('chmod %s %s "%s"' % (recursive, mode,  location))
 	if owner:
-		run_or_sudo('chown %s %s "%s"' % (recursive, owner, location))
+		run('chown %s %s "%s"' % (recursive, owner, location))
 	if group:
-		run_or_sudo('chgrp %s %s "%s"' % (recursive, group, location))
+		run('chgrp %s %s "%s"' % (recursive, group, location))
 
 def file_attribs_get(location):
 	"""Return mode, owner, and group for remote path.
